<?php
/**
 * Plugin Name: Everest Forms - Salesforce
 * Plugin URI: https://everestforms.net/features/salesforce/
 * Description: Everest Forms Salesforce addon allows you to integrate Salesforce into your forms.
 * Version: 1.0.2
 * Author: WPEverest
 * Author URI: https://wpeverest.com
 * Text Domain: everest-forms-salesforce
 * Domain Path: /languages/
 * Requires at least: 5.0
 * Requires PHP: 5.6.20
 *
 * EVF requires at least: 1.9.3
 * EVF tested up to: 3.0.0
 *
 * @package EverestForms\Salesforce
 */

defined( 'ABSPATH' ) || exit;

// Define plugin version.
if ( ! defined( 'EVF_SALESFORCE_VERSION' ) ) {
	define( 'EVF_SALESFORCE_VERSION', '1.0.2' );
}

// Define plugin root file.
if ( ! defined( 'EVF_SALESFORCE_PLUGIN_FILE' ) ) {
	define( 'EVF_SALESFORCE_PLUGIN_FILE', __FILE__ );
}

/**
 * Autoload packages.
 *
 * We want to fail gracefully if `composer install` has not been executed yet, so we are checking for the autoloader.
 * If the autoloader is not present, let's log the failure and display a nice admin notice.
 */
$autoloader = __DIR__ . '/vendor/autoload.php';
if ( is_readable( $autoloader ) ) {
	require $autoloader;
} else {
	if ( defined( 'WP_DEBUG' ) && WP_DEBUG ) {
		error_log( // phpcs:ignore WordPress.PHP.DevelopmentFunctions.error_log_error_log
			sprintf(
				/* translators: 1: composer command. 2: plugin directory */
				esc_html__( 'Your installation of the Everest Forms - Salesforce plugin is incomplete. Please run %1$s within the %2$s directory.', 'everest-forms-salesforce' ),
				'`composer install`',
				'`' . esc_html( str_replace( ABSPATH, '', __DIR__ ) ) . '`'
			)
		);
	}

	/**
	 * Outputs an admin notice if composer install has not been ran.
	 */
	add_action(
		'admin_notices',
		function() {
			?>
			<div class="notice notice-error">
				<p>
					<?php
					printf(
						/* translators: 1: composer command. 2: plugin directory */
						esc_html__( 'Your installation of the Everest Forms - Salesforce plugin is incomplete. Please run %1$s within the %2$s directory.', 'everest-forms-salesforce' ),
						'<code>composer install</code>',
						'<code>' . esc_html( str_replace( ABSPATH, '', __DIR__ ) ) . '</code>'
					);
					?>
				</p>
			</div>
			<?php
		}
	);
	return;
}

// Initialize the plugin.
add_action( 'plugins_loaded', array( 'EverestForms\\Salesforce\\Salesforce', 'instance' ) );
