<?php
/**
 * EverestForms Salesforce Admin.
 *
 * @package EverestForms\Salesforce\Settings\Integration
 * @since   1.0.0
 */

namespace EverestForms\Salesforce\Settings;

use EverestForms\Salesforce\API\API;

defined( 'ABSPATH' ) || exit;

/**
 * Salesforce Integration.
 *
 * @since 1.0.0
 */
class Integration extends \EVF_Integration {


	/**
	 * Init and hook in the integration.
	 */
	public function __construct() {
		$this->id                 = 'salesforce';
		$this->icon               = plugins_url( '/assets/images/salesforce.png', EVF_SALESFORCE_PLUGIN_FILE );
		$this->method_title       = esc_html__( 'Salesforce', 'everest-forms-salesforce' );
		$this->method_description = esc_html__( 'Salesforce Integration with Everest Forms', 'everest-forms-salesforce' );
		$this->authorize_url      = 'https://login.salesforce.com/services/oauth2/authorize';
		$connected_lists          = get_option( 'everest_forms_integrations', array() );

		if ( ! empty( $connected_lists[ $this->id ] ) ) {
			$this->account_status = 'connected';
		} else {
			$this->account_status = '';
		}

		add_action( 'init', array( $this, 'salesforce_token_page' ) );
	}

	/**
	 * Facilitates salesforce integration. Evoked from extensibility.
	 */
	public function output_integration() {
		$connected_lists = get_option( 'everest_forms_integrations', array() );
		if ( ! empty( $connected_lists['salesforce'] ) ) {
			$status_class = 'Connected';
		} else {
			$status_class = '';
		}
		?>
		<a href="<?php echo esc_url( admin_url( 'admin.php?page=evf-settings&tab=integration' ) ); ?>" class="everest-forms-integration-back-button">
			<span><?php echo esc_html__( 'Back', 'everest-forms-salesforce' ); ?></span>
		</a>
		<div class="everest-forms-integration-content">
			<div class="integration-addon-detail">
				<div class="evf-integration-info-header">
					<figure class="evf-integration-logo">
						<img src="<?php echo esc_attr( $this->icon ); ?>" alt="<?php echo esc_attr( 'test' ); ?>">
					</figure>
					<div class="integration-info">
						<h3><?php echo $this->method_title; /* phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped */ ?></h3>
						<div class="integration-status <?php echo $status_class; /* phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped */ ?>">
							<span class="toggle-switch connected"><?php echo $status_class; /* phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped */ ?></span>
						</div>
					</div>
				</div>
				<p><?php echo $this->method_description; /* phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped */ ?></p>
			</div>
			<div class="integration-connection-detail">
				<div class="evf-account-connect">
					<h3><?php esc_html_e( 'Add New Connection', 'everest-forms-salesforce' ); ?></h3>
					<p>
						<?php
						printf(
							/* translators: %1$s - Documentation Link Srarts; %2$s - Documentation Link ends. */
							esc_html__(
								'Get the Salesforce Consumer Key, we will use that code to authenticate with Salesforce. Follow the %1$s documentation %2$s to get Salesforce Consumer Key and Consumer Secret.',
								'everest-forms-salesforce'
							),
							'<a href="https://docs.wpeverest.com/everest-forms/docs/salesforce-crm/" target="_blank">',
							'</a>'
						);
						?>
					</p>
					<div class="evf-connection-form salesforce-connection-form">
						<label for="evf-salesforce-consumer-key"><?php esc_html_e( 'Consumer Key: ', 'everest-forms-salesforce' ); ?></label>
						<input type="text" data-name="client_id" id="evf-salesforce-consumer-key"  placeholder="Salesforce Consumer Key" class="everest_forms_salesforce_consuemr_key" required>
						<label for="evf-salesforce-consumer-secret"><?php esc_html_e( 'Consumer Secret:', 'everest-forms-salesforce' ); ?></label>
						<input type="text" data-name="client_secret" id="evf-salesforce-consumer-secret" placeholder="Salesforce Consumer Secret" class="everest_forms_salesforce_consumer_secret" required>
						<label><?php esc_html_e( 'Call Back URL', 'everest-forms-salesforce' ); ?></label>
						<input type="text" data-name="redirect_uri" placeholder="Call Back URL" class="everest_forms_salesforce_call_back_url" value="<?php echo esc_url_raw( rtrim( site_url(), '/' ) . '?evf-integration=salesforce' ); ?>" required>
					</div>
					<?php if ( empty( $this->auth_code ) ) : ?>
						<a href="<?php echo esc_url_raw( $this->authorize_url ); ?>" class="everest-forms-btn everest-forms-btn-primary everest-forms-integration-open-window" data-source="<?php echo esc_attr( $this->id ); ?>" data-redirect-uri="<?php echo esc_url_raw( rtrim( site_url(), '/' ) . '?page=evf-integration=salesforce' ); ?>">
							<?php esc_html_e( 'Authenticate with Salesforce account', 'everest-forms-pro' ); ?>
						</a>
					<?php else : ?>
						<a href="#" class="everest-forms-btn everest-forms-btn-secondary everest-forms-integration-disconnect-account" data-source="<?php echo esc_attr( $this->id ); ?>">
							<?php esc_html_e( 'Remove Authentication', 'everest-forms-pro' ); ?>
						</a>
					<?php endif; ?>
					<div class="evf-salesforce-account everest-forms-hidden">
						<label for="evf-salesfroce-nickname"><?php esc_html_e( 'Salesforce Account Nickname: ', 'everest-forms-salesforce' ); ?></label>
						<input type="text" placeholder="Salesforce Account Nickname" id="evf-salesforce-nickname" class="everest_forms_salesforce_account_name" required>
						<label for="evf-salesforce-auth-code"><?php esc_html_e( 'Salesforce Access Code: ', 'everest-forms-salesforce' ); ?></label>
						<input type="text" name="auth_code" if="evf-salesforce-auth-code" class="everest_forms_salesforce_auth_code" placeholder="<?php esc_attr_e( 'Enter Salesforce Access Code', 'everest-forms-salesforce' ); ?>" required>
						<button type="submit" class="everest-forms-btn everest-forms-btn-primary everest-forms-integration-connect-account" data-source="<?php echo esc_attr( $this->id ); ?>"><?php esc_html_e( 'Connect to Salesforce', 'everest-forms-salesforce' ); ?></button>
					</div>
				</div>
				<div class="evf-connection-list">
					<table class="evf-connection-list-table">
						<tbody>
							<?php
							if ( ! empty( $connected_lists['salesforce'] ) ) {
								foreach ( $connected_lists['salesforce'] as $key => $list ) {
									?>
									<tr>
										<td><strong><?php echo sanitize_text_field( $list['label'] ); /* phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped */ ?></strong></td>
										<td>Connected on <?php echo date_i18n( get_option( 'date_format' ), $list['date'] ); /* phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped */ ?></td>
										<td>
											<a href='#' class='disconnect everest-forms-integration-disconnect-account' data-source='salesforce' data-key='<?php echo esc_attr( $key ); ?>'><?php echo esc_html__( 'Disconnect', 'everest-forms-salesforce' ); ?></a>
										</td>
									</tr>
									<?php
								}
							}
							?>
						</tbody>
					</table>
				</div>
			</div>
		</div>
		<?php
	}

	/**
	 * Get Access Code.
	 *
	 * @since 1.0.0
	 */
	public function salesforce_token_page() {
		if ( isset( $_GET['evf-integration'] ) && 'salesforce' === sanitize_text_field( wp_unslash( $_GET['evf-integration'] ) ) ) {
			if ( isset( $_GET['code'] ) ) { // phpcs:ignore
				?>
				<!DOCTYPE html>
				<html lang="en">
					<head>
						<meta charset="UTF-8">
						<meta http-equiv="X-UA-Compatible" content="IE=edge">
						<meta name="viewport" content="width=device-width, initial-scale=1.0">
						<title>Salesforce - Access Code || Everest Forms</title>
						<style>
							.evf_salesforce_access_token input{
								width:100%;
							}
						</style>
					</head>
					<body>
						<div class="evf_salesforce_access_token" id="evf_salesforce_access_token" style="width:80%; margin:auto; margin-top: 80px;">
							<p><h3>Your Salesforce Access Code is: </h3></p>
							<br/>
							<p><input type="text" readonly value="<?php echo esc_attr( sanitize_text_field( wp_unslash( $_GET['code'] ) ) ); ?>"/></p>
						</div>
					</body>
				</html>
				<?php
				exit();
			}
		}
	}
}
