<?php
/**
 * EverestForms Salesforce Admin Settings
 *
 * @package EverestForms\Salesforce\Settings\Setting
 * @since   1.0.0
 */

namespace EverestForms\Salesforce\Settings;

use EverestForms\Salesforce\Api\Api;

defined( 'ABSPATH' ) || exit;


/**
 * Salesforce Setting Class.
 */
class Settings {

	/**
	 * Initialize.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		add_action( 'everest_forms_integration_account_connect_salesforce', array( $this, 'api_connect' ) );
	}

	/**
	 * API Connect Salesforce function.
	 *
	 * @param array $posted_data Has information on api connection & integration.
	 * @throws \Exception Exception.
	 */
	public function api_connect( $posted_data ) {

		if ( empty( $posted_data['everest_forms_salesforce_client_id'] ) ) {
			wp_send_json_error(
				array(
					'error_msg' => esc_html__( 'Invalid Salesforce Client ID.', 'everest-forms-salesforce' ),
				)
			);
		}

		if ( empty( $posted_data['everest_forms_salesforce_client_secret'] ) ) {
			wp_send_json_error(
				array(
					'error_msg' => esc_html__( 'Salesforce Client Secret is required.', 'everest-forms-salesforce' ),
				)
			);
		}

		if ( empty( $posted_data['everest_forms_salesforce_access_code'] ) ) {
			wp_send_json_error(
				array(
					'error_msg' => esc_html__( 'Salesforce Access Code is required.', 'everest-forms-salesforce' ),
				)
			);
		}

		if ( empty( $posted_data['everest_forms_salesforce_account_name'] ) ) {
			wp_send_json_error(
				array(
					'error_msg' => esc_html__( 'Salesforce account nickname is required.', 'everest-forms-salesforce' ),
				)
			);
		}

		try {

			$connection_args = array(
				'client_id'     => trim( $posted_data['everest_forms_salesforce_client_id'] ),
				'client_secret' => trim( $posted_data['everest_forms_salesforce_client_secret'] ),
				'label'         => trim( $posted_data['everest_forms_salesforce_account_name'] ),
				'auth_code'     => trim( $posted_data['everest_forms_salesforce_access_code'] ),
				'connection_id' => uniqid(),
				'status'        => true,
				'date'          => time(),
				'instance_url'  => '',

			);

			$api = new Api( $connection_args );

			$connection = $api->get_connection();

			if ( ! is_wp_error( $connection ) ) {
				$output  = '<tr>';
				$output .= '<td><strong>' . esc_html( $connection['label'] ) . '</strong></td>';
				/* translators: %s: Date of connection. */
				$output .= '<td>' . sprintf( esc_html__( 'Connected on: %s', 'everest-forms-salesforce' ), date_i18n( get_option( 'date_format', $connection['date'] ) ) ) . '</td>';
				$output .= '<td><a href="#" class="disconnect everest-forms-integration-disconnect-account" data-source="' . esc_attr( $_POST['source'] ) . '" data-key="' . esc_attr( $connection['connection_id']  ) . '">' . esc_html__( 'Disconnect', 'everest-forms-salesforce' ) . '</a></td>';
				$output .= '</tr>';

				wp_send_json_success(
					array(
						'html' => $output,
					)
				);
			} else {
				$error_message = $connection->get_error_message();
				throw new \Exception( "`{$error_message}` for Salesforce" );
			}
		} catch ( \Exception $e ) {
			wp_send_json_error(
				array(
					'error'     => esc_html__( 'Could not connect to the provider.', 'everest-forms-salesforce' ),
					'error_msg' => $e->getMessage(),
				)
			);
		}
	}
}
